"""
Module for generate config dict from configserver
"""

import os
import requests
from logger import logger


class ConfigServer:
    """Encapsulate config dict avoiding
       developers to modify this content"""

    CONFIG_HOST = '{}{}/{}{}.json'

    def __init__(self):

        logger.debug('Requesting configuration file')

        config_address = os.environ['CONFIGSERVER_ADDRESS']
        branch = '/' + os.environ['CONFIGSERVER_BRANCH']
        app_name = os.environ['APP_NAME']
        profile = '-' + os.environ['PROFILES']

        if branch == '/':
            branch = ''

        config_host = os.path.join(self.CONFIG_HOST.format(config_address, branch, app_name, profile))

        logger.debug(f'Config host url: {config_host}')
        response = requests.get(config_host)
        self._config_content = response.json()

        logger.debug(f'Config content: {self._config_content}')
        logger.debug('Config file taked')

    def get_atribute(self, key_attr):
        """
        Get a atribute from configuration file
        use . to define a path on a key tree
        """

        key_list = key_attr.split('.')
        atribute_content = self._config_content.get(key_list[0])

        for key in key_list[1:]:
            atribute_content = atribute_content.get(key)
            
        logger.debug('Getting atribute from content')

        return atribute_content

    def get_keys(self):
        """
        List all keys from config file
        """

        keys = self._config_content.keys()

        logger.debug('Gettings keys from config file')

        return keys



import pika
import time
from pika.exceptions import ConnectionClosed


class RMQConnection:
    """Config connection with rabbit rmq"""

    WAIT_SECONDS_FOR_CONNECTION = 60

    def __init__(self, host, routing_key):

        parameters = pika.ConnectionParameters(host)
        self._connection = self._set_up_connection(parameters)
        self._channel = self._connection.channel()

        self._channel.exchange_declare(exchange='acl_entry',
                                       exchange_type='topic')

        queue = self._channel.queue_declare(exclusive=True)

        self._queue_name = queue.method.queue

        self._channel.queue_bind(exchange='acl_entry',
                                 queue=self._queue_name,
                                 routing_key=routing_key)

    def get_consume(self):
        return self._channel.consume(self._queue_name)

    def return_ack(self, method):
        """
        Return delivery tag
        """
        self._channel.basic_ack(method.delivery_tag)

    def _set_up_connection(self, parameters):
        """
        Return a Blocking connection
        """

        conn = None

        for _ in range(self.WAIT_SECONDS_FOR_CONNECTION):

            try:
                conn = pika.BlockingConnection(parameters)
            except ConnectionClosed:
                time.sleep(1)

        return conn



from setuptools import setup 

setup(name='gpam-stfdigital',
      version='0.1',
      description='Client for integrate service with STF Digital',
      url='https://supremotribunalfederal.gitlab.io/',
      author='GPAM',
      author_email='gpamunb@gmail.com',
      license='MIT',
      packages=[    
                'gpam-stfdigital'
                ],
     zip_safe=False)



import logging
import os
import traceback
import sys

# TODO: Modularize code (create methods or functions)

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter('[%(levelname)s]%(module)s:%(lineno)d'
                              '{%(funcName)s}:%(message)s')

handler = logging.StreamHandler(sys.stdout)
handler.setFormatter(formatter)

fh = logging.FileHandler('/logs/textos.log')

formatter = logging.Formatter('{"@timestamp":"%(asctime)s",'
                              '"@version":1,'
                              '"message": "%(message)s",'
                              '"logger_name": "%(module)s",'
                              '"thread_name": "%(threadName)s",'
                              '"level": "%(levelname)s",'
                              '"level_value": "%(levelno)s",'
                              '"stack_trace": "' +
                              traceback.format_exc().strip() + '",'
                              '"app_name": "textos"}')

fh.setFormatter(formatter)

fh.setLevel(logging.DEBUG)

logger.addHandler(fh)
logger.addHandler(handler)
